<?php
/**
 * Alleria functions and definitions
 *
 * @package Alleria
 */

if ( ! function_exists( 'alleria_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function alleria_setup() {

        /**
         * Set the content width based on the theme's design and stylesheet.
         */
        global $content_width;
        if (!isset($content_width)) { $content_width = 500; }

        add_image_size('featured-img', 1080, 450, true);
        
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Alleria, use a find and replace
	 * to change 'alleria' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'alleria', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/*
	 * Add theme support for document Title tag.
	 *
	 * @link https://codex.wordpress.org/Title_Tag
	 */ 
	add_theme_support( 'title-tag' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'alleria' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'alleria_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // alleria_setup
add_action( 'after_setup_theme', 'alleria_setup' );


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function alleria_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'alleria' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Widget Area', 'alleria' ),
		'id'            => 'footer-widget-area',
		'description'   => 'Widget area above the footer',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'alleria_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function alleria_scripts() {
        wp_enqueue_style( 'alleria-style', get_stylesheet_uri() );
        wp_enqueue_style( 'dashicons' );
        wp_register_style('alleria-googleFonts', 'http://fonts.googleapis.com/css?family=Lemon');
        wp_enqueue_style( 'alleria-googleFonts');

        wp_enqueue_script( 'alleria-scrollfix', get_template_directory_uri() . '/js/scrollfix.js', array(), '20120206', true );
        wp_enqueue_script( 'alleria-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
        wp_enqueue_script( 'alleria-sticky', get_template_directory_uri() . '/js/sticky.js', array(), '20150206', true );
        wp_enqueue_script( 'masonry', array( 'jquery' ) );
        wp_enqueue_script( 'alleria-alleria', get_template_directory_uri() . '/js/alleria.js', array('jquery'), '', true );
        wp_enqueue_script( 'alleria-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
                wp_enqueue_script( 'comment-reply' );
        }
}
add_action( 'wp_enqueue_scripts', 'alleria_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Add a keep reading link after posts with automatic excerpts longer than the set length.
 */
function alleria_read_more_link() {
	return '... <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">' . __(' keep reading &rarr;', 'alleria') . '</a>';
}
add_filter( 'excerpt_more', 'alleria_read_more_link' );